@@ -26,6 +26,7 @@
 #include "e-node.h"
 #include "shield.h"
 #include "linker.h"
+#include "tunnel.h"
 
 Circuit* Circuit::m_pSelf = NULL;
 
@@ -33,6 +34,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
        : QGraphicsScene( x, y, width, height, parent )
 {
     m_simulator = new Simulator();
+    Tunnel::clearTunnels();
 
     setObjectName( "Circuit" );
     setParent( parent );
@@ -70,8 +72,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
                      this,&Circuit::saveBackup, Qt::UniqueConnection );
 
     qDebug() << endl << "-------------------------------------------------";
-    qDebug() << "                   NEW CIRCUIT                   ";
-    qDebug() << "-------------------------------------------------"<<endl;
+    qDebug() << "                   NEW CIRCUIT                   "<<endl;
 }
 
 Circuit::~Circuit()
