@@ -11,7 +11,7 @@
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT Mosfet : public Component, public eMosfet
+class Mosfet : public Component, public eMosfet
 {
     public:
         Mosfet( QString type, QString id );
@@ -22,7 +22,10 @@ class MAINMODULE_EXPORT Mosfet : public Component, public eMosfet
 
         virtual void updateStep() override;
 
-        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget );
+        virtual void setPchannel( bool p ) override;
+        virtual void setDepletion( bool d ) override;
+
+        virtual void paint( QPainter* p, const QStyleOptionGraphicsItem* o, QWidget* w ) override;
 };
 
 #endif
