@@ -56,8 +56,11 @@ MuxAnalog::MuxAnalog( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new IntProp <MuxAnalog>("Address_Bits", tr("Address Size"),"_Bits", this, &MuxAnalog::addrBits,  &MuxAnalog::setAddrBits, propNoCopy,"uint" ),
-new DoubProp<MuxAnalog>("Impedance"   , tr("Impedance")   ,"Ω"    , this, &MuxAnalog::impedance, &MuxAnalog::setImpedance ),
+new IntProp <MuxAnalog>("Address_Bits", tr("Address Size"),"_bits"
+                       , this, &MuxAnalog::addrBits, &MuxAnalog::setAddrBits, propNoCopy,"uint" ),
+
+new DoubProp<MuxAnalog>("Impedance"   , tr("Impedance"),"Ω"
+                        , this, &MuxAnalog::impedance, &MuxAnalog::setImpedance ),
     },0} );
 }
 MuxAnalog::~MuxAnalog(){}
@@ -89,6 +92,7 @@ void MuxAnalog::updateStep()
 
 void MuxAnalog::voltChanged()
 {
+    bool oldEnabled = m_enabled;
     m_enabled = m_enPin->getVoltage() < 2.5;
 
     int address = 0;
@@ -97,9 +101,9 @@ void MuxAnalog::voltChanged()
         bool state = (m_addrPin[i]->getVoltage()>2.5);
         if( state ) address += pow( 2, i );
     }
+    if ( oldEnabled != m_enabled || address != m_address )
+        Simulator::self()->addEvent( 10000/*m_propDelay*/, this );
     m_address = address;
-
-    Simulator::self()->addEvent( 10000/*m_propDelay*/, this );
 }
 
 void MuxAnalog::runEvent()
@@ -220,4 +224,6 @@ void MuxAnalog::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWid
 {
     Component::paint( p, option, widget );
     p->drawRoundRect( m_area, 4, 4 );
+
+    Component::paintSelected( p );
 }
