@@ -39,16 +39,17 @@ Buffer::Buffer( QString type, QString id )
     },0} );
     addPropGroup( { tr("Electric"), IoComponent::inputProps()
 +QList<ComProperty*>({
-new BoolProp<Buffer>("Invert_Inputs", tr("Invert Inputs"),"", this
-                    , &Buffer::invertInps, &Buffer::setInvertInps, propNoCopy )
+new BoolProp<Buffer>("Invert_Inputs", tr("Invert Inputs"),""
+                    , this, &Buffer::invertInps, &Buffer::setInvertInps, propNoCopy )
                     })
-                    +IoComponent::outputProps()+IoComponent::outputType()
+                    +Gate::outputProps()+IoComponent::outputType()
 +QList<ComProperty*>({
-new BoolProp<Buffer>("Tristate", tr("Tristate"),"", this
-                     , &Buffer::tristate, &Buffer::setTristate, propNoCopy )
+new BoolProp<Buffer>("Tristate", tr("Tristate"),""
+                    , this, &Buffer::tristate, &Buffer::setTristate, propNoCopy )
                     })
     ,0} );
-    addPropGroup( { tr("Edges") , Gate::edgeProps(),0 } );
+
+    addPropGroup( { tr("Timing"), IoComponent::edgeProps(),0 } );
 
     removeProperty("pd_n");
 }
@@ -86,4 +87,6 @@ void Buffer::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget
         QPointF( 8,-1 )             };
 
     p->drawPolygon( points, 4 );
+
+    Component::paintSelected( p );
 }
