@@ -49,10 +49,11 @@ Bus::Bus( QString type, QString id )
     m_busPin0->setIsBus( true );
 
     addPropGroup( { tr("Main"), {
-new IntProp<Bus>("Num_Bits" , tr("Size"),"_Bits", this
-                , &Bus::numLines, &Bus::setNumLines, propNoCopy,"uint" ),
+new IntProp<Bus>("Num_Bits" , tr("Size"),"_bits"
+                , this, &Bus::numLines, &Bus::setNumLines, propNoCopy,"uint" ),
 
-new IntProp<Bus>("Start_Bit", tr("Start Bit"),"", this, &Bus::startBit, &Bus::setStartBit,0,"uint" )
+new IntProp<Bus>("Start_Bit", tr("Start Bit"),""
+                , this, &Bus::startBit, &Bus::setStartBit,0,"uint" )
     }, groupNoCopy } );
 }
 Bus::~Bus(){}
@@ -82,6 +83,7 @@ void Bus::setNumLines( int lines )
 
     m_pin.resize( lines+2 );
     m_ePin.resize( lines+2 );
+    m_signalPin.clear();
     
     for( int i=1; i<=lines; i++ )
     {
@@ -93,6 +95,7 @@ void Bus::setNumLines( int lines )
         pin->setLabelText( " "+QString::number( m_startBit+i-1 )+" " );
         m_pin[i]  = pin;
         m_ePin[i] = pin;
+        m_signalPin.append( pin );
     }
     m_busPin1->setPos( QPoint( 0 ,-lines*8+8 ) );
     m_busPin1->isMoved();
@@ -101,6 +104,8 @@ void Bus::setNumLines( int lines )
 
     m_height = lines-1;
     m_area = QRect( -3,-m_height*8-2, 5, m_height*8+4 );
+
+    setflip();
     Circuit::self()->update();
 }
 
@@ -127,4 +132,6 @@ void Bus::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* w
 
     p->drawRect( QRect( 0, -m_height*8, 0, m_height*8 ) );
               //QRect( -2, -m_height*8-4, 2, m_height*8+8 );
+
+    Component::paintSelected( p );
 }
