@@ -70,17 +70,17 @@ Memory::Memory( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-        new IntProp <Memory>("Address_Bits", tr("Address Size"),"_Bits", this
-                    , &Memory::addrBits, &Memory::setAddrBits, propNoCopy,"uint" ),
+new IntProp <Memory>("Address_Bits", tr("Address Size"),"_bits"
+                    , this, &Memory::addrBits, &Memory::setAddrBits, propNoCopy,"uint" ),
 
-        new IntProp <Memory>("Data_Bits", tr("Data Size")   ,"_Bits", this
-                    , &Memory::dataBits, &Memory::setDataBits, propNoCopy,"uint" ),
+new IntProp <Memory>("Data_Bits", tr("Data Size"),"_bits"
+                    , this, &Memory::dataBits, &Memory::setDataBits, propNoCopy,"uint" ),
 
-        new BoolProp<Memory>("Persistent", tr("Persistent"),"", this
-                    , &Memory::persistent, &Memory::setPersistent ),
+new BoolProp<Memory>("Persistent", tr("Persistent"),""
+                    , this, &Memory::persistent, &Memory::setPersistent ),
 
-        new BoolProp<Memory>("Asynch", tr("Asynchronous"),"", this
-                    , &Memory::asynchro, &Memory::setAsynchro )
+new BoolProp<Memory>("Asynch", tr("Asynchronous"),""
+                    , this, &Memory::asynchro, &Memory::setAsynchro )
     }, groupNoCopy} );
 
     addPropGroup( { tr("Electric")
@@ -89,13 +89,13 @@ Memory::Memory( QString type, QString id )
         + IoComponent::outputType()
     ,0 } );
 
-    addPropGroup( { tr("Edges")
+    addPropGroup( { tr("Timing")
         , IoComponent::edgeProps()
     ,0 } );
 
     addPropGroup( { "Hidden", {
-        new StrProp<Memory>("Mem","","", this
-                , &Memory::getMem, &Memory::setMem)
+new StrProp<Memory>("Mem","",""
+                   , this, &Memory::getMem, &Memory::setMem)
     }, groupHidden} );
 }
 Memory::~Memory(){}
@@ -135,13 +135,13 @@ void Memory::voltChanged()        // Some Pin Changed State, Manage it
     bool cs = m_CsPin->getInpState();
     bool we = m_WePin->getInpState();
     bool oe = cs && !we && m_oePin->getInpState(); // Enable output buffers only if OE & CS & Read
-    if( m_oe != oe )
+    if( m_oe != oe || m_cs != cs || m_we != we )
     {
         m_oe = oe;
         for( IoPin* pin : m_outPin )         // Enable/Disable output buffers
         {
             pin->setPinMode( oe ? output : input );
-            if( m_asynchro ) pin->changeCallBack( this, m_cs && m_we );
+            if( m_asynchro ) pin->changeCallBack( this, cs && we );
         }
     }
     // Operate only if Asynchronous or change in CS or WE
