@@ -58,18 +58,19 @@ Mux::Mux( QString type, QString id )
     setAddrBits( 3 );
 
     addPropGroup( { tr("Main"), {
-new IntProp<Mux>("Address_Bits" , tr("Address Size") ,"_bits", this
-                , &Mux::addrBits, &Mux::setAddrBits, propNoCopy )
+new IntProp<Mux>("Address_Bits" , tr("Address Size") ,"_bits"
+                , this, &Mux::addrBits, &Mux::setAddrBits, propNoCopy )
     }, groupNoCopy } );
 
     addPropGroup( { tr("Electric"), IoComponent::inputProps()
         +QList<ComProperty*>({
-        new BoolProp<Mux>( "Invert_Inputs", tr("Invert Inputs"),"", this
-                , &Mux::invertInps, &Mux::setInvertInps, propNoCopy )})
-        +IoComponent::outputProps()
+new BoolProp<Mux>( "Invert_Inputs", tr("Invert Inputs"),""
+                 , this, &Mux::invertInps, &Mux::setInvertInps, propNoCopy )
+                    })
+        + IoComponent::outputProps()
     ,0 } );
 
-    addPropGroup( { tr("Edges"), IoComponent::edgeProps(),0 } );
+    addPropGroup( { tr("Timing"), IoComponent::edgeProps(),0 } );
 }
 Mux::~Mux(){}
 
@@ -173,4 +174,6 @@ void Mux::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* w
         QPointF( w,-h+2 )};
 
     p->drawPolygon(points, 4);
+
+    Component::paintSelected( p );
 }
