@@ -16,13 +16,16 @@
 #include "datawidget.h"
 #include "tunnel.h"
 #include "e-node.h"
+#include "iopin.h"
 
 #include "stringprop.h"
 #include "doubleprop.h"
 #include "intprop.h"
 
-Component* Oscope::construct( QObject* parent, QString type, QString id )
-{ return new Oscope( parent, type, id ); }
+#define tr(str) simulideTr("Oscope",str)
+
+Component* Oscope::construct( QString type, QString id )
+{ return new Oscope( type, id ); }
 
 LibraryItem* Oscope::libraryItem()
 {
@@ -34,8 +37,8 @@ LibraryItem* Oscope::libraryItem()
         Oscope::construct );
 }
 
-Oscope::Oscope( QObject* parent, QString type, QString id )
-      : PlotBase( parent, type, id )
+Oscope::Oscope( QString type, QString id )
+      : PlotBase( type, id )
 {
     m_numChannels = 4;
     m_trigger = 4;
@@ -50,12 +53,15 @@ Oscope::Oscope( QObject* parent, QString type, QString id )
     m_display->setPlotBase( this );
     m_display->setFixedSize( m_baSizeX+6*8, m_baSizeY+2*8 );
 
+    m_inPin.resize(5);
     m_pin.resize(5);
-    m_pin[4] = new Pin( 180, QPoint( -80-8, 64 ), id+"-PinG", 0, this );
+    m_pin[4] = m_inPin[4] = new IoPin( 180, QPoint(-80-8, 64 ), id+"-PinG", 0, this, input );
 
     for( int i=0; i<4; i++ )
     {
-        m_pin[i] = new Pin( 180, QPoint( -80-8,-48+32*i ), id+"-Pin"+QString::number(i), 0, this );
+        m_pin[i] = m_inPin[i] = new IoPin( 180, QPoint(-80-8,-48+32*i ), id+"-Pin"+QString::number(i), 0, this, undef_mode );
+        double admit = m_connectGnd ? m_inputAdmit : 0;
+        m_inPin[i]->setInputAdmit( admit );
         m_channel[i] = new OscopeChannel( this, id+"Chan"+QString::number(i) );
         m_channel[i]->m_channel = i;
         m_channel[i]->m_ePin[0] = m_pin[i];
@@ -79,12 +85,23 @@ Oscope::Oscope( QObject* parent, QString type, QString id )
     expand( false );
 
     addPropGroup( { "Hidden1", {
-new DoubProp<Oscope>("Filter", tr("Filter"), "V", this, &Oscope::filter, &Oscope::setFilter ),
-new IntProp <Oscope>("Trigger","", "", this, &Oscope::trigger, &Oscope::setTrigger ),
-new IntProp <Oscope>("AutoSC" ,"", "", this, &Oscope::autoSC,  &Oscope::setAutoSC ),
-new IntProp <Oscope>("Tracks" ,"", "", this, &Oscope::tracks,  &Oscope::setTracks ),
-new StrProp <Oscope>("HideCh" ,"", "", this, &Oscope::hideCh,  &Oscope::setHideCh ),
-new StrProp <Oscope>("VolPos" ,"", "", this, &Oscope::volPos,  &Oscope::setVolPos )
+new DoubProp<Oscope>("Filter", "", "V"
+                    , this, &Oscope::filter, &Oscope::setFilter ),
+
+new IntProp <Oscope>("Trigger","", ""
+                    , this, &Oscope::trigger, &Oscope::setTrigger ),
+
+new IntProp <Oscope>("AutoSC" ,"", ""
+                    , this, &Oscope::autoSC, &Oscope::setAutoSC ),
+
+new IntProp <Oscope>("Tracks" ,"", ""
+                    , this, &Oscope::tracks, &Oscope::setTracks ),
+
+new StrProp <Oscope>("HideCh" ,"", ""
+                    , this, &Oscope::hideCh, &Oscope::setHideCh ),
+
+new StrProp <Oscope>("VolPos" ,"", ""
+                    , this, &Oscope::volPos, &Oscope::setVolPos )
     }, groupHidden } );
 }
 Oscope::~Oscope()
@@ -103,45 +120,54 @@ void Oscope::updateStep()
     uint64_t timeFrame = m_timeDiv*10;
     uint64_t simTime;
 
-    if( m_trigger < 4  ) period = m_channel[m_trigger]->m_period; // We want a trigger
-
-    if( period > 10 ) // We have a Trigger
+    if( !Simulator::self()->isPaused() )
     {
-        uint64_t risEdge = m_channel[m_trigger]->m_risEdge;
+        if( m_trigger < 4  ) period = m_channel[m_trigger]->m_period; // We want a trigger
 
-        uint64_t nCycles = timeFrame/period;
-        if( timeFrame%period ) nCycles++;
-        if( nCycles%2 )        nCycles++;
-
-        uint64_t delta = nCycles*period/2-timeFrame/2;
-        if( delta > risEdge ) delta = risEdge;
-        simTime = risEdge-delta;
-    }
-    else simTime = Simulator::self()->circTime(); // free running
-
-    m_display->setTimeEnd( simTime );
-
-    for( int i=0; i<4; i++ )
-    {
-        bool connected = m_pin[i]->connector();
-        if( !connected )
+        if( period > 10 ) // We have a Trigger
         {
-            QString chTunnel = m_channel[i]->m_chTunnel;
+            uint64_t risEdge = m_channel[m_trigger]->m_risEdge;
 
-            eNode* enode = Tunnel::getEnode( chTunnel );
-            m_pin[i]->setEnode( enode );
-            if( enode )
+            uint64_t nCycles = timeFrame/period;
+            if( timeFrame%period ) nCycles++;
+            if( nCycles%2 )        nCycles++;
+
+            uint64_t delta = nCycles*period/2-timeFrame/2;
+            if( delta > risEdge ) delta = risEdge;
+            simTime = risEdge-delta;
+        }
+        else simTime = Simulator::self()->circTime(); // free running
+
+        m_display->setTimeEnd( simTime );
+
+        for( int i=0; i<4; i++ )
+        {
+            bool connected = m_pin[i]->connector();
+            if( !connected )
             {
-                enode->voltChangedCallback( m_channel[i] );
-                connected = true;
+                QString chTunnel = m_channel[i]->m_chTunnel;
+
+                eNode* enode = Tunnel::getEnode( chTunnel );
+                m_pin[i]->setEnode( enode );
+                if( enode )
+                {
+                    enode->voltChangedCallback( m_channel[i] );
+                    connected = true;
+                }
+                display()->connectChannel( i, connected );
             }
-            display()->connectChannel( i, connected );
+            m_channel[i]->m_connected = connected;
+            if( connected ) m_channel[i]->updateStep();
+            m_channel[i]->m_trigIndex = m_channel[i]->m_bufferCounter;
         }
-        m_channel[i]->m_connected = connected;
-        if( connected ) m_channel[i]->updateStep();
-        m_channel[i]->m_trigIndex = m_channel[i]->m_bufferCounter;
     }
-    m_display->update(); //redrawScreen();
+    m_display->update();
+
+    if( m_changed ){
+        m_changed = false;
+        double admit = m_connectGnd ? m_inputAdmit : 0;
+        for( IoPin* pin : m_inPin ) pin->stampAdmitance( admit );
+    }
 }
 
 void Oscope::expand( bool e )
