@@ -17,7 +17,7 @@
 #include "boolprop.h"
 #include "intprop.h"
 
-#define tr(str) simulideTr("TouchPadR",str)
+#define tr(str) simulideTr("TouchPad",str)
 
 Component* TouchPad::construct( QString type, QString id )
 { return new TouchPad( type, id ); }
@@ -25,7 +25,7 @@ Component* TouchPad::construct( QString type, QString id )
 LibraryItem* TouchPad::libraryItem()
 {
     return new LibraryItem(
-        tr( "TouchPad (Resistive)" ),
+        tr("TouchPad (Resistive)"),
         "Peripherals",
         "touch.png",
         "TouchPadR",
@@ -33,20 +33,22 @@ LibraryItem* TouchPad::libraryItem()
 }
 
 TouchPad::TouchPad( QString type, QString id )
-     : Component( type, id )
-     , eElement( id )
-     , m_resXA( id+"-resXA" )
-     , m_resXB( id+"-resXB" )
-     , m_resYA( id+"-resYA" )
-     , m_resYB( id+"-resYB" )
-     , m_resTouch( id+"-resTouch" )
-     , m_ePinXA( id+"-ePinXA", 1 )
-     , m_ePinXB( id+"-ePinXB", 1 )
-     , m_ePinYA( id+"-ePinYA", 1 )
-     , m_ePinYB( id+"-ePinYB", 1 )
-     , m_ePinTA( id+"-ePinTA", 1 )
-     , m_ePinTB( id+"-ePinTB", 1 )
+        : Component( type, id )
+        , eElement( id )
+        , m_resXA( id+"-resXA" )
+        , m_resXB( id+"-resXB" )
+        , m_resYA( id+"-resYA" )
+        , m_resYB( id+"-resYB" )
+        , m_resTouch( id+"-resTouch" )
+        , m_ePinXA( id+"-ePinXA", 1 )
+        , m_ePinXB( id+"-ePinXB", 1 )
+        , m_ePinYA( id+"-ePinYA", 1 )
+        , m_ePinYB( id+"-ePinYB", 1 )
+        , m_ePinTA( id+"-ePinTA", 1 )
+        , m_ePinTB( id+"-ePinTB", 1 )
 {
+    m_graphical = true;
+
     m_eNodeX = NULL;
     m_eNodeY = NULL;
 
@@ -98,15 +100,28 @@ TouchPad::TouchPad( QString type, QString id )
     Simulator::self()->addToUpdateList( this );
 
     addPropGroup( { tr("Main"), {
-new IntProp <TouchPad>("Width", tr("Width")    ,"_Pixels", this, &TouchPad::width      , &TouchPad::setWidth ,0,"uint" ),
-new IntProp <TouchPad>("Height",tr("Height")   ,"_Pixels", this, &TouchPad::height     , &TouchPad::setHeight ,0,"uint" ),
-new BoolProp<TouchPad>("Transparent",tr("Transparent"),"", this, &TouchPad::transparent, &TouchPad::setTransparent )
+new IntProp <TouchPad>("Width", tr("Width"),"_px"
+                      , this, &TouchPad::width, &TouchPad::setWidth ,0,"uint" ),
+
+new IntProp <TouchPad>("Height",tr("Height"),"_px"
+                        , this, &TouchPad::height, &TouchPad::setHeight ,0,"uint" ),
+
+new BoolProp<TouchPad>("Transparent",tr("Transparent"),""
+                        , this, &TouchPad::transparent, &TouchPad::setTransparent )
     }, groupNoCopy} );
+
     addPropGroup( { tr("Electric"), {
-new DoubProp<TouchPad>("RxMin", tr("RxMin"),"Ω", this, &TouchPad::RxMin, &TouchPad::setRxMin,0,"uint" ),
-new DoubProp<TouchPad>("RxMax", tr("RxMax"),"Ω", this, &TouchPad::RxMax, &TouchPad::setRxMax,0,"uint" ),
-new DoubProp<TouchPad>("RyMin", tr("RyMin"),"Ω", this, &TouchPad::RyMin, &TouchPad::setRyMin,0,"uint" ),
-new DoubProp<TouchPad>("RyMax", tr("RyMax"),"Ω", this, &TouchPad::RyMax, &TouchPad::setRyMax,0,"uint" ),
+new DoubProp<TouchPad>("RxMin", tr("RxMin"),"Ω"
+                      , this, &TouchPad::RxMin, &TouchPad::setRxMin,0,"uint" ),
+
+new DoubProp<TouchPad>("RxMax", tr("RxMax"),"Ω"
+                      , this, &TouchPad::RxMax, &TouchPad::setRxMax,0,"uint" ),
+
+new DoubProp<TouchPad>("RyMin", tr("RyMin"),"Ω"
+                      , this, &TouchPad::RyMin, &TouchPad::setRyMin,0,"uint" ),
+
+new DoubProp<TouchPad>("RyMax", tr("RyMax"),"Ω"
+                      , this, &TouchPad::RyMax, &TouchPad::setRyMax,0,"uint" ),
     }, groupNoCopy} );
 }
 TouchPad::~TouchPad(){}
@@ -259,7 +274,10 @@ void TouchPad::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidg
     p->setBrush( Qt::transparent );
     p->drawRoundedRect( QRect(-m_width/2,-m_height-2, m_width, m_height ), 2, 2 );
 
-    p->setBrush( QColor(50, 70, 100) );
-    p->drawRoundedRect( QRect(-20,-2, 40, 18 ), 2, 2 );
+    if( !m_hidden ){
+        p->setBrush( QColor(50, 70, 100) );
+        p->drawRoundedRect( QRect(-20,-2, 40, 18 ), 2, 2 );
+    }
+    Component::paintSelected( p );
 }
 
