@@ -39,7 +39,8 @@ Header::Header( QString type, QString id )
     m_color = QColor( 65, 65, 65 );
 
     this->addProperty( tr("Main"),
-new BoolProp<Header>( "Down", tr("Downwards"),"", this, &Header::pointDown, &Header::setPointDown ));
+new BoolProp<Header>("Down", tr("Downwards"),""
+                    , this, &Header::pointDown, &Header::setPointDown ));
 }
 Header::~Header(){}
 
@@ -48,14 +49,19 @@ void Header::setPointDown( bool down )
     m_pointDown = down;
     Pin::pinType_t type;
 
-    if( down ) { m_pinPixmap.load( ":/header_D.png" ); type = Pin::pinNormal; }
-    else       { m_pinPixmap.load( ":/header_U.png" ); type = Pin::pinHeader; }
+    type = down ? Pin::pinNormal :Pin::pinHeader;
 
     for( int i=0; i<m_size; i++ )
     {
         m_sockPins[i]->setFlag( QGraphicsItem::ItemStacksBehindParent, down );
         m_sockPins[i]->setPinType( type );
     }
+    updatePixmap();
+}
+
+void Header::updatePins()
+{
+    setPointDown( m_pointDown );
 }
 
 void Header::updatePixmap()
