@@ -32,7 +32,7 @@ Component* WaveGen::construct( QString type, QString id )
 LibraryItem* WaveGen::libraryItem()
 {
     return new LibraryItem(
-        tr("Wave Gen."),
+        tr("Wave Generator"),
         "Sources",
         "wavegen.png",
         "WaveGen",
@@ -45,6 +45,7 @@ WaveGen::WaveGen( QString type, QString id )
     m_bipolar  = false;
     m_floating = false;
     m_voltBase = -2.5;
+    m_phaseShift = 0;
     m_voltMid  = 0;
     m_lastVout = 0;
     m_waveType = Sine;
@@ -77,12 +78,13 @@ WaveGen::WaveGen( QString type, QString id )
 
     remPropGroup( tr("Main") );
     addPropGroup( { tr("Main"), {
-new StrProp <WaveGen>("Wave_Type", tr("Wave Type"),""      , this, &WaveGen::waveType, &WaveGen::setWaveType,0,"enum" ),
-new DoubProp<WaveGen>("Freq"     , tr("Frequency"),"Hz"    , this, &WaveGen::freq,     &WaveGen::setFreq ),
-new IntProp <WaveGen>("Steps"    , tr("Quality")  ,"_Steps", this, &WaveGen::steps,    &WaveGen::setSteps ),
-new DoubProp<WaveGen>("Duty"     , tr("Duty")     ,"_\%"   , this, &WaveGen::duty,     &WaveGen::setDuty ),
-new StrProp <WaveGen>("File"     , tr("File"),""           , this, &WaveGen::fileName, &WaveGen::setFile ),
-new BoolProp<WaveGen>("Always_On", tr("Always On"),""      , this, &WaveGen::alwaysOn, &WaveGen::setAlwaysOn )
+new StrProp <WaveGen>("Wave_Type", tr("Wave Type")  ,""      , this, &WaveGen::waveType,  &WaveGen::setWaveType,0,"enum" ),
+new DoubProp<WaveGen>("Freq"     , tr("Frequency")  ,"Hz"    , this, &WaveGen::freq,      &WaveGen::setFreq ),
+new DoubProp<WaveGen>("Phase"    , tr("Phase shift"),"_º"    , this, &WaveGen::phaseShift,&WaveGen::setPhaseShift ),
+new IntProp <WaveGen>("Steps"    , tr("Quality")    ,"_Steps", this, &WaveGen::steps,     &WaveGen::setSteps ),
+new DoubProp<WaveGen>("Duty"     , tr("Duty")       ,"_\%"   , this, &WaveGen::duty,      &WaveGen::setDuty ),
+new StrProp <WaveGen>("File"     , tr("File")       ,""      , this, &WaveGen::fileName,  &WaveGen::setFile ),
+new BoolProp<WaveGen>("Always_On", tr("Always On")  ,""      , this, &WaveGen::alwaysOn,  &WaveGen::setAlwaysOn )
     },0} );
     addPropGroup( { tr("Electric"), {
 new BoolProp<WaveGen>("Bipolar"   , tr("Bipolar")       ,"" , this, &WaveGen::bipolar,   &WaveGen::setBipolar, propNoCopy ),
@@ -122,21 +124,21 @@ void WaveGen::stamp()
         m_outpin->createCurrent();
         m_gndpin->createCurrent();
 
-        m_outpin->setImp( cero_doub );
-        m_gndpin->setImp( cero_doub );
+        m_outpin->setImpedance( cero_doub );
+        m_gndpin->setImpedance( cero_doub );
     }
     else{
         m_outpin->skipStamp( false );
         m_gndpin->skipStamp( false );
 
-        m_outpin->setImp( cero_doub );
-        m_gndpin->setImp( cero_doub );
+        m_outpin->setImpedance( cero_doub );
+        m_gndpin->setImpedance( cero_doub );
     }
 }
 
 void WaveGen::runEvent()
 {
-    m_time = fmod( (Simulator::self()->circTime()-m_lastTime), m_fstepsPC );
+    m_time = fmod( (Simulator::self()->circTime()-m_lastTime) - m_stepsPC*m_phaseShift/360, m_fstepsPC );
     
     if     ( m_waveType == Sine )     genSine();
     else if( m_waveType == Saw )      genSaw();
@@ -256,7 +258,7 @@ void WaveGen::setBipolar(bool b )
     if( b ) m_outpin->setY( -4 );
     else    m_outpin->setY( 0 );
 
-    udtProperties();
+    updtProperties();
 }
 
 void WaveGen::setFloating( bool f )
@@ -266,7 +268,7 @@ void WaveGen::setFloating( bool f )
 
     if( Simulator::self()->isRunning() ) CircuitWidget::self()->powerCircOff();
 
-    udtProperties();
+    updtProperties();
 }
 
 void WaveGen::setWaveType( QString t )
@@ -287,11 +289,11 @@ void WaveGen::setWaveType( QString t )
     }
     if( m_wavePixmap ) delete m_wavePixmap;
     m_wavePixmap = new QPixmap( pixmapPath );
-    udtProperties();
+    updtProperties();
     update();
 }
 
-void WaveGen::udtProperties()
+void WaveGen::updtProperties()
 {
     if( !m_propDialog ) return;
 
@@ -311,12 +313,13 @@ void WaveGen::udtProperties()
 
     //m_propDialog->showProp("Mid_Volt", !m_bipolar || !m_floating );
     m_propDialog->showProp("Floating", m_bipolar );
+    m_propDialog->adjustWidgets();
 }
 
 void WaveGen::slotProperties()
 {
     Component::slotProperties();
-    udtProperties();
+    updtProperties();
 }
 
 void WaveGen::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu )
@@ -494,4 +497,6 @@ void WaveGen::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidge
 
     p->drawRoundedRect( m_area,2 ,2 );
     p->drawPixmap( m_area.x()+3, m_area.y()+4,16, 8, *m_wavePixmap );
+
+    Component::paintSelected( p );
 }
