@@ -38,9 +38,9 @@ Push::Push( QString type, QString id )
     SetupSwitches( 1, 1 );
 
     addPropGroup( { tr("Main"), {
-new BoolProp<Push>("Norm_Close", tr("Normally Closed"),""      , this, &Push::nClose, &Push::setNClose ),
-new IntProp <Push>("Poles"     , tr("Poles")          ,"_Poles", this, &Push::poles,  &Push::setPoles, propNoCopy,"uint" ),
-new StrProp <Push>("Key"       , tr("Key")            ,""      , this, &Push::key,    &Push::setKey ),
+new BoolProp<Push>("Norm_Close", tr("Normally Closed"),"", this, &Push::nClose, &Push::setNClose ),
+new IntProp <Push>("Poles"     , tr("Poles")          ,"", this, &Push::poles,  &Push::setPoles, propNoCopy,"uint" ),
+new StrProp <Push>("Key"       , tr("Key")            ,"", this, &Push::key,    &Push::setKey ),
     }, 0} );
 }
 Push::~Push(){}
@@ -67,4 +67,6 @@ void Push::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget*
         pen.setWidth(1);
         p->setPen(pen);
         p->drawLine(-0, 4-4*m_pin0, 0,-3*m_pin0-16*m_numPoles+4 );
-}   }
+    }
+    Component::paintSelected( p );
+}
