@@ -7,6 +7,7 @@
 #include "component.h"
 #include "propdialog.h"
 #include "comproperty.h"
+//#include "mainwindow.h"
 
 BoolVal::BoolVal( PropDialog* parent, CompBase* comp, ComProperty* prop )
        : PropVal( parent, comp, prop )
@@ -24,6 +25,11 @@ void BoolVal::setup( bool )
     trueVal->setChecked( checked );
     m_blocked = false;
 
+    //float scale = MainWindow::self()->fontScale();
+    //QFont font = trueVal->font();
+    //font.setPixelSize( 11.0*scale );
+    //trueVal->setFont( font );
+
     this->adjustSize();
 }
 
@@ -38,6 +44,8 @@ void BoolVal::on_trueVal_toggled( bool checked )
 
 void BoolVal::updtValues()
 {
+    m_blocked = true;
     bool checked = (m_property->getValStr() == "true");
     trueVal->setChecked( checked );
+    m_blocked = false;
 }
