@@ -8,7 +8,7 @@
 
 #include "shield.h"
 
-class MAINMODULE_EXPORT ModuleSubc : public ShieldSubc
+class ModuleSubc : public ShieldSubc
 {
     public:
         ModuleSubc( QString type, QString id );
@@ -17,8 +17,9 @@ class MAINMODULE_EXPORT ModuleSubc : public ShieldSubc
         double zVal() { return zValue(); }
         void setZVal( double v);
 
+        virtual void slotAttach() override;
+
     protected:
-        virtual void attachToBoard() override;
         virtual void renameTunnels() override;
 };
 #endif
