@@ -37,10 +37,15 @@ Component* SubCircuit::construct( QString type, QString id )
 
     QString name;
     QStringList list = id.split("-");
-    if( list.size() > 1 ) name = list.at( list.size()-2 ); // for example: "atmega328-1" to: "atmega328"
+    if( list.size() > 1 ){
+        name = list.at( list.size()-2 ); // for example: "atmega328-1" to: "atmega328"
+        list.takeLast();
+    }
 
-    if     ( name.contains("@") ) list = name.split("@");
+    int rev = MainWindow::self()->revision();
+    if( rev >= 2220 ){ if( name.contains("@") ) list = name.split("@");}
     else if( name.contains("_") ) list = name.split("_");
+
     if( list.size() > 1 )  // Subcircuit inside Subcircuit: 1_74HC00 to 74HC00
     {
         QString n = list.first();
@@ -311,7 +316,7 @@ void SubCircuit::loadSubCircuit( QString file )
                         if( l->hasLinks() ) linkList.append( l );
                     }
 
-                    if( type == "Tunnel" ) // Make Tunnel names unique for this subcircuit
+                    if( type == "Tunnel" ) // Make Circuit Tunnel names unique for this subcircuit
                     {
                         Tunnel* tunnel = static_cast<Tunnel*>( comp );
                         tunnel->setTunnelUid( tunnel->name() );
@@ -342,7 +347,7 @@ Pin* SubCircuit::addPin( QString id, QString type, QString label, int pos, int x
         tunnel->setAcceptedMouseButtons( Qt::NoButton );
         tunnel->setShowId( false );
         tunnel->setTunnelUid( id );
-        tunnel->setName( pId ); // Make tunel name unique for this component
+        tunnel->setName( pId );           // Make Pin Tunel names unique for this component
         tunnel->setPos( xpos, ypos );
         tunnel->setPacked( true );
         if( type == "bus" ) tunnel->setIsbus( true );
@@ -381,7 +386,7 @@ Pin* SubCircuit::updatePin( QString id, QString type, QString label, int xpos, i
     tunnel->setIsbus( type == "bus" );
 
     if     ( angle == 180) tunnel->setRotation( 0 );
-    else if( angle == 90 ) tunnel->setRotation( -90 ); // QGraphicsItem 0º i at right side
+    else if( angle == 90 ) tunnel->setRotation(-90 ); // QGraphicsItem 0º i at right side
     else                   tunnel->setRotation( angle );
 
     pin  = tunnel->getPin();
@@ -452,12 +457,14 @@ void SubCircuit::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
 
     for( Component* mainComp : m_mainComponents.values() )
     {
-        QString compType = mainComp->getUid();
-        int pos  = compType.indexOf("_")+1;
-        int len  = compType.lastIndexOf("-")-pos;
-        compType = compType.mid( pos, len );
+        QString name = mainComp->idLabel();
+        int pos = 0;
+        if( name.contains("@") ) pos = name.lastIndexOf("@")+1;
 
-        QMenu* submenu = menu->addMenu( QIcon(":/subc.png"), compType );
+        int len  = name.length()-pos;
+        name = name.mid( pos, len );
+
+        QMenu* submenu = menu->addMenu( QIcon(":/subc.png"), name );
 
         mainComp->contextMenu( NULL, submenu );
     }
