@@ -50,6 +50,8 @@ LibraryItem* SubPackage::libraryItem()
 SubPackage::SubPackage( QString type, QString id )
           : Chip( type, id )
 {
+    m_linkCursor = QCursor( QPixmap(":/expose.png"), 10, 10 );
+
     m_subcType = Chip::None;
     m_width  = 4;
     m_height = 8;
@@ -68,6 +70,7 @@ SubPackage::SubPackage( QString type, QString id )
 
     m_boardModeAction = new QAction( tr("Board Mode") );
     m_boardModeAction->setCheckable( true );
+    QObject::connect( m_boardModeAction, &QAction::triggered, [=](){ boardModeSlot(); } );
     m_boardMode = false;
     
     setAcceptHoverEvents( true );
@@ -96,16 +99,17 @@ void SubPackage::setSubcTypeStr( QString s )
     subcType_t type = (subcType_t)index;
     if( m_subcType == type ) return;
 
+    SubPackage* currentBoard = Circuit::self()->getBoard();
     if( type >= Board )
     {
-        if( Circuit::self()->getBoard() ) // Only one board Package can be in the circuit
+        if( currentBoard && currentBoard != this ) // Only one board Package can be in the circuit
         {
             qDebug() << "SubPackage::setSubcTypeStr: ERROR: Only one Board allowed";
             return;
         }
         Circuit::self()->setBoard( this );
     }
-    else if( Circuit::self()->getBoard() == this ) Circuit::self()->setBoard( NULL );
+    else if( currentBoard == this ) Circuit::self()->setBoard( NULL );
 
     m_subcType = type;
 
@@ -185,8 +189,7 @@ void SubPackage::mousePressEvent( QGraphicsSceneMouseEvent* event )
         QColor color = m_isLS ? Qt::black : QColor( 250, 250, 200 );
 
         m_eventPin = new PackagePin( m_angle, QPoint(m_p1X,m_p1Y ), "name", 0, this );
-        ///m_eventPin->setEnabled( false );
-        m_eventPin->setFlag( QGraphicsItem::ItemStacksBehindParent, false );
+
         m_eventPin->setPinId( "Id" );
         m_eventPin->setLabelColor( color );
         m_eventPin->setLabelPos();
@@ -214,7 +217,6 @@ void SubPackage::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
     {
         m_boardModeAction->setChecked( m_boardMode );
         menu->addAction( m_boardModeAction );
-        QObject::connect( m_boardModeAction, &QAction::triggered, [=](){ boardModeSlot(); } );
     }
     QAction* mainCompAction = menu->addAction( QIcon(":/subcl.png"),tr("Select Exposed Components") );
     QObject::connect( mainCompAction, &QAction::triggered, [=](){ mainComp(); } );
@@ -225,6 +227,7 @@ void SubPackage::contextMenu( QGraphicsSceneContextMenuEvent* event, QMenu* menu
 void SubPackage::compSelected( Component* comp )
 {
     if( comp) comp->setMainComp( !comp->isMainComp() );
+    else      Linker::compSelected( comp );
 }
 
 void SubPackage::boardModeSlot()
@@ -246,20 +249,32 @@ void SubPackage::setBoardMode( bool mode )
     for( Component* comp : *Circuit::self()->compList() )
     {
         if( comp->itemType() == "Package" ) continue;
-        if( mode )
+
+        if( mode )   // We are in Board mode
         {
             comp->setCircPos( comp->pos() );
             comp->setCircRot( comp->rotation() );
-            if( comp->boardRot() != -1e+6 )  // Board Position already defined
+            comp->setCircHflip( comp->hflip() );
+            comp->setCircVflip( comp->vflip() );
+
+            if( comp->boardRot() != -1e+6 )  // Board Rotation already defined
             {
                 comp->setPos( comp->boardPos() + this->pos() );
                 comp->setRotation( comp->boardRot() );
-        }   }
-        else{
+                comp->setHflip( comp->boardHflip() );
+                comp->setVflip( comp->boardVflip() );
+            }
+        }else        // We are in Circuit mode
+        {
             comp->setBoardPos( comp->pos()-this->pos() );
             comp->setBoardRot( comp->rotation() );
+            comp->setBoardHflip( comp->hflip() );
+            comp->setBoardVflip( comp->vflip() );
+
             comp->setPos( comp->circPos() );
             comp->setRotation( comp->circRot() );
+            comp->setHflip( comp->circHflip() );
+            comp->setVflip( comp->circVflip() );
         }
         comp->setHidden( mode, false, mode );
     }
@@ -273,12 +288,11 @@ void SubPackage::remove()
         = QMessageBox::warning( 0l, "SubPackage::remove",
                                tr("\nPackage has been modified.\n"
                                   "Do you want to save your changes?\n"),
-                               QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel);
+                               QMessageBox::Save | QMessageBox::Discard );
                                
-        if     ( ret == QMessageBox::Save ) slotSave();
-        else if( ret == QMessageBox::Cancel ) return;
+        if( ret == QMessageBox::Save ) slotSave();
     }
-    Component::remove();
+    Circuit::self()->compRemoved( true );
 }
 
 void SubPackage::setWidth( int width )
@@ -308,7 +322,6 @@ void SubPackage::setHeight( int height )
 Pin* SubPackage::addPin( QString id, QString type, QString label, int pos, int xpos, int ypos, int angle, int length, int space )
 {
     PackagePin* pin = new PackagePin( angle, QPoint(xpos, ypos), m_id+"-"+id, pos-1, this ); // pos in package starts at 1
-    //pin->setEnabled( false );
 
     QColor color = m_isLS ? Qt::black : QColor( 250, 250, 200 );
 
@@ -318,8 +331,8 @@ Pin* SubPackage::addPin( QString id, QString type, QString label, int pos, int x
     pin->setLength( length );
     pin->setSpace( space );
     pin->setLabelText( label );
+    pin->setIsBus( type == "bus" );
     pin->setInverted( type == "inverted" || type == "inv" );
-    //pin->setFlag( QGraphicsItem::ItemStacksBehindParent, false );
 
     m_pkgePins.append( pin );
     return pin;
@@ -348,7 +361,7 @@ void SubPackage::deleteEventPin()
     m_changed = true;
 
     m_pkgePins.removeOne( m_eventPin );
-    m_signalPin.removeOne( m_eventPin );
+    //m_signalPin.removeOne( m_eventPin ); // ToDelete
     delete m_eventPin;
     m_eventPin = NULL;
     
@@ -378,7 +391,7 @@ void SubPackage::setPinAngle( int i )
     update();
 }
 
-void SubPackage::setPinSpace( int space )
+void SubPackage::setPinSpace( double space )
 {
     m_eventPin->setSpace( space );
 }
@@ -397,7 +410,7 @@ void SubPackage::unusePin( bool unuse )
     m_changed = true;
 }
 
-void SubPackage::pointPin( bool point )
+void SubPackage::setPointPin( bool point )
 {
     int length = 8;
     if( point ) length = 1;
@@ -414,7 +427,14 @@ void SubPackage::pointPin( bool point )
     else if( m_angle == 90 )  m_eventPin->moveBy( 0,-deltaL );// Top
     else if( m_angle == 270 ) m_eventPin->moveBy( 0, deltaL );// Bottom
 
-    m_eventPin->setFlag( QGraphicsItem::ItemStacksBehindParent, false );
+    Circuit::self()->update();
+    m_changed = true;
+}
+
+void SubPackage::setBusPin( bool bus )
+{
+    m_eventPin->setIsBus( bus );
+
     Circuit::self()->update();
     m_changed = true;
 }
@@ -553,8 +573,10 @@ QString SubPackage::pinEntry( Pin* pin )
     QString label  = "label=\""+pin->getLabelText().replace("<","&#x3C;").replace("=","&#x3D;").replace(">","&#x3E;")+"\"";
     QString space  = "space=\""+QString::number( pin->space() )+"\"";
     QString type;
-    if( pin->inverted() ) type = "inv";
-    if( pin->unused()   ) type = "nc";
+    if     ( pin->unused()   ) type = "nc";
+    else if( pin->isBus()    ) type = "bus";
+    else if( pin->inverted() ) type = "inv";
+
     type = "type=\""+type+"\"";
 
     return "    <pin "
@@ -616,8 +638,8 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     idLayout->addWidget( m_idLabel );
     idLayout->addWidget( m_idLineEdit );
 
-    m_spaceLabel = new QLabel( tr("Name Space:") );
-    m_spaceBox = new QSpinBox();
+    m_spaceLabel = new QLabel( tr("Space to Label:") );
+    m_spaceBox   = new QDoubleSpinBox();
     m_spaceBox->setValue( eventPin->space() );
     QHBoxLayout* spaceLayout = new QHBoxLayout;
     spaceLayout->addWidget( m_spaceLabel );
@@ -644,6 +666,9 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     m_pointCheckBox = new QCheckBox(tr("Point Pin"));
     m_pointCheckBox->setChecked( (eventPin->length() < 7) );
 
+    m_busCheckBox = new QCheckBox(tr("Bus Pin"));
+    m_busCheckBox->setChecked( eventPin->isBus() );
+
     QDialogButtonBox* bb = new QDialogButtonBox( QDialogButtonBox::Ok );
     QPushButton* okBtn = bb->button(QDialogButtonBox::Ok);
     okBtn->setAutoDefault(true);
@@ -657,8 +682,16 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     layout->addWidget( m_invertCheckBox );
     layout->addWidget( m_unuseCheckBox );
     layout->addWidget( m_pointCheckBox );
+    layout->addWidget( m_busCheckBox );
     layout->addWidget( bb );
 
+    QFontMetrics fm( m_nameLabel->font() );
+    double scale = fm.width(" ")/2.0;
+    m_nameLineEdit->setFixedWidth( 60*scale );
+    m_idLineEdit->setFixedWidth( 60*scale );
+    m_spaceBox->setFixedWidth( 60*scale );
+    m_angleBox->setFixedWidth( 60*scale );
+
     setLayout( layout );
     setWindowTitle( tr("Edit Pin ")+eventPin->getLabelText() );
 
@@ -670,8 +703,8 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
     QObject::connect( m_idLineEdit, &QLineEdit::textEdited,
                       [=](const QString &s){ m_package->setPinId(s); } );
 
-    QObject::connect( m_spaceBox, QOverload<int>::of(&QSpinBox::valueChanged),
-                      [=](int s){ m_package->setPinSpace(s); } );
+    QObject::connect( m_spaceBox, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
+                      [=](double s){ m_package->setPinSpace(s); } );
 
     QObject::connect( m_angleBox, QOverload<int>::of(&QComboBox::currentIndexChanged),
                       [=](int a){ m_package->setPinAngle(a); }  );
@@ -683,15 +716,21 @@ EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
                       [=](bool t){ m_package->unusePin(t); } );
 
     QObject::connect( m_pointCheckBox,  &QCheckBox::toggled,
-                      [=](bool t){ m_package->pointPin(t); } );
+                      [=](bool t){ this->setPointPin(t); } );
+
+    QObject::connect( m_busCheckBox,  &QCheckBox::toggled,
+                      [=](bool t){ this->setBusPin(t); } );
 }
 
-void EditDialog::invertPin( bool invert )
+void EditDialog::setPointPin( bool p )
 {
-    QString id = m_idLineEdit->text();
-    if( invert && !id.startsWith("!") ) id.prepend("!");
-    else if( !invert && id.startsWith("!") ) id.remove( 0, 1 );
-
-    m_idLineEdit->setText( id );
-    m_package->invertPin( invert );
+    m_package->setPointPin( p );
+    if( m_invertCheckBox->isChecked() ) m_invertCheckBox->setChecked( !p );
 }
+
+void EditDialog::setBusPin( bool b )
+{
+    m_package->setBusPin( b );
+    if( m_invertCheckBox->isChecked() ) m_invertCheckBox->setChecked( !b );
+}
+
