@@ -31,6 +31,7 @@ void Interrupt::reset()
     //m_mode    = 0;
     m_enabled = 0;
     m_raised  = false;
+    m_continuous = false;
 }
 
 void Interrupt::enableFlag( uint8_t en )
@@ -65,24 +66,28 @@ void Interrupt::flagCleared( uint8_t )  // Interrupt flag was cleared by softwar
 void Interrupt::writeFlag( uint8_t v ) // Clear Interrupt flag by writting 1 to it
 {
     if( v & m_flagMask ){
-        clearFlag();
-        m_mcu->m_regOverride = m_ram[m_flagReg];
+        int overrided = m_mcu->m_regOverride;
+        if( overrided > 0 ) v = overrided;      // Get previous overrides
+        m_mcu->m_regOverride = v & ~m_flagMask; // Clear flag
+        flagCleared();      // Pin INT continuous while low level
     }
 }
 
 void Interrupt::raise( uint8_t v )
 {
-    if( v && !m_raised ){
+    if( v ){
+        if( m_raised ) return;
         m_raised = true;
-        m_ram[m_flagReg] |= m_flagMask; // Set Interrupt flag
 
+        if( !m_continuous ) m_ram[m_flagReg] |= m_flagMask; // Set Interrupt flag
+                                                            // Continuous don't set the flag (AVR Pin INT)
         if( m_enabled )
         {
             m_interrupts->addToPending( this ); // Add to pending interrupts
             if( m_intPin ) m_intPin->setOutState( false );
 
-            if( m_mcu->isSleeping()
-             && m_wakeup & m_mcu->sleepMode() )
+            if( m_mcu->state() == mcuSleeping
+             && (m_wakeup & m_mcu->sleepMode()) )
                 m_mcu->sleep( false ); // Exit sleep
         }
         if( !m_callBacks.isEmpty() ) { for( McuModule* mod : m_callBacks ) mod->callBack(); }
